require 'spec_helper'

describe 'chef' do
  context 'supported operating systems' do
    on_supported_os.each do |os, facts|
      context "on #{os}" do
        let(:facts) do
          facts
        end

        context "chef class without any parameters" do
          it { is_expected.to compile.with_all_deps }

          it { is_expected.to contain_class('chef::params') }
          it { is_expected.to contain_class('chef::install').that_comes_before('chef::config') }
          it { is_expected.to contain_class('chef::config') }
          it { is_expected.to contain_class('chef::service').that_subscribes_to('chef::config') }

          it { is_expected.to contain_service('chef') }
          it { is_expected.to contain_package('chef').with_ensure('present') }
        end
      end
    end
  end

  context 'unsupported operating system' do
    describe 'chef class without any parameters on Solaris/Nexenta' do
      let(:facts) do
        {
          :osfamily        => 'Solaris',
          :operatingsystem => 'Nexenta',
        }
      end

      it { expect { is_expected.to contain_package('chef') }.to raise_error(Puppet::Error, /Nexenta not supported/) }
    end
  end
end
